# Generated file. To retain edits, remove this comment.

from pathlib import Path
import os
from typing import Dict, Tuple, Optional, List, Any

from .js_package import js_package

from itkwasm.pyodide import (
    to_js,
    to_py,
    js_resources
)
from itkwasm import (
    InterfaceTypes,
    BinaryFile,
    TextStream,
)

async def structured_report_to_text_async(
    dicom_file: os.PathLike,
    unknown_relationship: bool = False,
    invalid_item_value: bool = False,
    ignore_constraints: bool = False,
    ignore_item_errors: bool = False,
    skip_invalid_items: bool = False,
    no_document_header: bool = False,
    number_nested_items: bool = False,
    shorten_long_values: bool = False,
    print_instance_uid: bool = False,
    print_sopclass_short: bool = False,
    print_sopclass_long: bool = False,
    print_sopclass_uid: bool = False,
    print_all_codes: bool = False,
    print_invalid_codes: bool = False,
    print_template_id: bool = False,
    indicate_enhanced: bool = False,
    print_color: bool = False,
) -> str:
    """Read a DICOM structured report file and generate a plain text representation

    :param dicom_file: Input DICOM file
    :type  dicom_file: os.PathLike

    :param unknown_relationship: Accept unknown relationship type
    :type  unknown_relationship: bool

    :param invalid_item_value: Accept invalid content item value
    :type  invalid_item_value: bool

    :param ignore_constraints: Ignore relationship constraints
    :type  ignore_constraints: bool

    :param ignore_item_errors: Ignore content item errors
    :type  ignore_item_errors: bool

    :param skip_invalid_items: Skip invalid content items
    :type  skip_invalid_items: bool

    :param no_document_header: Print no document header
    :type  no_document_header: bool

    :param number_nested_items: Number nested items
    :type  number_nested_items: bool

    :param shorten_long_values: Shorten long item values
    :type  shorten_long_values: bool

    :param print_instance_uid: Print SOP Instance UID
    :type  print_instance_uid: bool

    :param print_sopclass_short: Print short SOP class name
    :type  print_sopclass_short: bool

    :param print_sopclass_long: Print SOP class name
    :type  print_sopclass_long: bool

    :param print_sopclass_uid: Print long SOP class name
    :type  print_sopclass_uid: bool

    :param print_all_codes: Print all codes
    :type  print_all_codes: bool

    :param print_invalid_codes: Print invalid codes
    :type  print_invalid_codes: bool

    :param print_template_id: Print template identification
    :type  print_template_id: bool

    :param indicate_enhanced: Indicate enhanced encoding mode
    :type  indicate_enhanced: bool

    :param print_color: Use ANSI escape codes
    :type  print_color: bool

    :return: Output text file
    :rtype:  str
    """
    js_module = await js_package.js_module
    web_worker = js_resources.web_worker

    kwargs = {}
    if unknown_relationship:
        kwargs["unknownRelationship"] = to_js(unknown_relationship)
    if invalid_item_value:
        kwargs["invalidItemValue"] = to_js(invalid_item_value)
    if ignore_constraints:
        kwargs["ignoreConstraints"] = to_js(ignore_constraints)
    if ignore_item_errors:
        kwargs["ignoreItemErrors"] = to_js(ignore_item_errors)
    if skip_invalid_items:
        kwargs["skipInvalidItems"] = to_js(skip_invalid_items)
    if no_document_header:
        kwargs["noDocumentHeader"] = to_js(no_document_header)
    if number_nested_items:
        kwargs["numberNestedItems"] = to_js(number_nested_items)
    if shorten_long_values:
        kwargs["shortenLongValues"] = to_js(shorten_long_values)
    if print_instance_uid:
        kwargs["printInstanceUid"] = to_js(print_instance_uid)
    if print_sopclass_short:
        kwargs["printSopclassShort"] = to_js(print_sopclass_short)
    if print_sopclass_long:
        kwargs["printSopclassLong"] = to_js(print_sopclass_long)
    if print_sopclass_uid:
        kwargs["printSopclassUid"] = to_js(print_sopclass_uid)
    if print_all_codes:
        kwargs["printAllCodes"] = to_js(print_all_codes)
    if print_invalid_codes:
        kwargs["printInvalidCodes"] = to_js(print_invalid_codes)
    if print_template_id:
        kwargs["printTemplateId"] = to_js(print_template_id)
    if indicate_enhanced:
        kwargs["indicateEnhanced"] = to_js(indicate_enhanced)
    if print_color:
        kwargs["printColor"] = to_js(print_color)

    outputs = await js_module.structuredReportToText(web_worker, to_js(BinaryFile(dicom_file)), **kwargs)

    output_web_worker = None
    output_list = []
    outputs_object_map = outputs.as_object_map()
    for output_name in outputs.object_keys():
        if output_name == 'webWorker':
            output_web_worker = outputs_object_map[output_name]
        else:
            output_list.append(to_py(outputs_object_map[output_name]))

    js_resources.web_worker = output_web_worker

    if len(output_list) == 1:
        return output_list[0]
    return tuple(output_list)



# Generated file. To retain edits, remove this comment.

from pathlib import Path
import os
from typing import Dict, Tuple, Optional, List, Any

from .js_package import js_package

from itkwasm.pyodide import (
    to_js,
    to_py,
    js_resources
)
from itkwasm import (
    InterfaceTypes,
    BinaryFile,
    BinaryStream,
)

async def read_dicom_encapsulated_pdf_async(
    dicom_file: os.PathLike,
    read_file_only: bool = False,
    read_dataset: bool = False,
    read_xfer_auto: bool = False,
    read_xfer_detect: bool = False,
    read_xfer_little: bool = False,
    read_xfer_big: bool = False,
    read_xfer_implicit: bool = False,
    accept_odd_length: bool = False,
    assume_even_length: bool = False,
    enable_cp246: bool = False,
    disable_cp246: bool = False,
    retain_un: bool = False,
    convert_un: bool = False,
    enable_correction: bool = False,
    disable_correction: bool = False,
) -> bytes:
    """Extract PDF file from DICOM encapsulated PDF.

    :param dicom_file: Input DICOM file
    :type  dicom_file: os.PathLike

    :param read_file_only: read file format only
    :type  read_file_only: bool

    :param read_dataset: read data set without file meta information
    :type  read_dataset: bool

    :param read_xfer_auto: use TS recognition (default)
    :type  read_xfer_auto: bool

    :param read_xfer_detect: ignore TS specified in the file meta header
    :type  read_xfer_detect: bool

    :param read_xfer_little: read with explicit VR little endian TS
    :type  read_xfer_little: bool

    :param read_xfer_big: read with explicit VR big endian TS
    :type  read_xfer_big: bool

    :param read_xfer_implicit: read with implicit VR little endian TS
    :type  read_xfer_implicit: bool

    :param accept_odd_length: accept odd length attributes (default)
    :type  accept_odd_length: bool

    :param assume_even_length: assume real length is one byte larger
    :type  assume_even_length: bool

    :param enable_cp246: read undefined len UN as implicit VR (default)
    :type  enable_cp246: bool

    :param disable_cp246: read undefined len UN as explicit VR
    :type  disable_cp246: bool

    :param retain_un: retain elements as UN (default)
    :type  retain_un: bool

    :param convert_un: convert to real VR if known
    :type  convert_un: bool

    :param enable_correction: enable automatic data correction (default)
    :type  enable_correction: bool

    :param disable_correction: disable automatic data correction
    :type  disable_correction: bool

    :return: Output pdf file
    :rtype:  bytes
    """
    js_module = await js_package.js_module
    web_worker = js_resources.web_worker

    kwargs = {}
    if read_file_only:
        kwargs["readFileOnly"] = to_js(read_file_only)
    if read_dataset:
        kwargs["readDataset"] = to_js(read_dataset)
    if read_xfer_auto:
        kwargs["readXferAuto"] = to_js(read_xfer_auto)
    if read_xfer_detect:
        kwargs["readXferDetect"] = to_js(read_xfer_detect)
    if read_xfer_little:
        kwargs["readXferLittle"] = to_js(read_xfer_little)
    if read_xfer_big:
        kwargs["readXferBig"] = to_js(read_xfer_big)
    if read_xfer_implicit:
        kwargs["readXferImplicit"] = to_js(read_xfer_implicit)
    if accept_odd_length:
        kwargs["acceptOddLength"] = to_js(accept_odd_length)
    if assume_even_length:
        kwargs["assumeEvenLength"] = to_js(assume_even_length)
    if enable_cp246:
        kwargs["enableCp246"] = to_js(enable_cp246)
    if disable_cp246:
        kwargs["disableCp246"] = to_js(disable_cp246)
    if retain_un:
        kwargs["retainUn"] = to_js(retain_un)
    if convert_un:
        kwargs["convertUn"] = to_js(convert_un)
    if enable_correction:
        kwargs["enableCorrection"] = to_js(enable_correction)
    if disable_correction:
        kwargs["disableCorrection"] = to_js(disable_correction)

    outputs = await js_module.readDicomEncapsulatedPdf(web_worker, to_js(BinaryFile(dicom_file)), **kwargs)

    output_web_worker = None
    output_list = []
    outputs_object_map = outputs.as_object_map()
    for output_name in outputs.object_keys():
        if output_name == 'webWorker':
            output_web_worker = outputs_object_map[output_name]
        else:
            output_list.append(to_py(outputs_object_map[output_name]))

    js_resources.web_worker = output_web_worker

    if len(output_list) == 1:
        return output_list[0]
    return tuple(output_list)



# Generated file. To retain edits, remove this comment.

from pathlib import Path
import os
from typing import Dict, Tuple, Optional, List, Any

from .js_package import js_package

from itkwasm.pyodide import (
    to_js,
    to_py,
    js_resources
)
from itkwasm import (
    InterfaceTypes,
    BinaryFile,
    TextStream,
    TextFile,
)

async def structured_report_to_html_async(
    dicom_file: os.PathLike,
    read_file_only: bool = False,
    read_dataset: bool = False,
    read_xfer_auto: bool = False,
    read_xfer_detect: bool = False,
    read_xfer_little: bool = False,
    read_xfer_big: bool = False,
    read_xfer_implicit: bool = False,
    processing_details: bool = False,
    unknown_relationship: bool = False,
    invalid_item_value: bool = False,
    ignore_constraints: bool = False,
    ignore_item_errors: bool = False,
    skip_invalid_items: bool = False,
    disable_vr_checker: bool = False,
    charset_require: bool = False,
    charset_assume: str = "",
    charset_check_all: bool = False,
    convert_to_utf8: bool = False,
    url_prefix: str = "",
    html_32: bool = False,
    html_40: bool = False,
    xhtml_11: bool = False,
    add_document_type: bool = False,
    css_reference: Optional[str] = None,
    css_file: Optional[os.PathLike] = None,
    expand_inline: bool = False,
    never_expand_inline: bool = False,
    always_expand_inline: bool = False,
    render_full_data: bool = False,
    section_title_inline: bool = False,
    document_type_title: bool = False,
    patient_info_title: bool = False,
    no_document_header: bool = False,
    render_inline_codes: bool = False,
    concept_name_codes: bool = False,
    numeric_unit_codes: bool = False,
    code_value_unit: bool = False,
    code_meaning_unit: bool = False,
    render_all_codes: bool = False,
    code_details_tooltip: bool = False,
) -> str:
    """Render DICOM SR file and data set to HTML/XHTML

    :param dicom_file: Input DICOM file
    :type  dicom_file: os.PathLike

    :param read_file_only: read file format only
    :type  read_file_only: bool

    :param read_dataset: read data set without file meta information
    :type  read_dataset: bool

    :param read_xfer_auto: use TS recognition (default)
    :type  read_xfer_auto: bool

    :param read_xfer_detect: ignore TS specified in the file meta header
    :type  read_xfer_detect: bool

    :param read_xfer_little: read with explicit VR little endian TS
    :type  read_xfer_little: bool

    :param read_xfer_big: read with explicit VR big endian TS
    :type  read_xfer_big: bool

    :param read_xfer_implicit: read with implicit VR little endian TS
    :type  read_xfer_implicit: bool

    :param processing_details: show currently processed content item
    :type  processing_details: bool

    :param unknown_relationship: accept unknown/missing relationship type
    :type  unknown_relationship: bool

    :param invalid_item_value: accept invalid content item value (e.g. violation of VR or VM definition)
    :type  invalid_item_value: bool

    :param ignore_constraints: ignore relationship content constraints
    :type  ignore_constraints: bool

    :param ignore_item_errors: do not abort on content item errors, just warn (e.g. missing value type specific attributes)
    :type  ignore_item_errors: bool

    :param skip_invalid_items: skip invalid content items (incl. sub-tree)
    :type  skip_invalid_items: bool

    :param disable_vr_checker: disable check for VR-conformant string values
    :type  disable_vr_checker: bool

    :param charset_require: require declaration of ext. charset (default)
    :type  charset_require: bool

    :param charset_assume: [c]harset: string, assume charset c if no extended charset declared
    :type  charset_assume: str

    :param charset_check_all: check all data elements with string values (default: only PN, LO, LT, SH, ST, UC and UT)
    :type  charset_check_all: bool

    :param convert_to_utf8: convert all element values that are affected by Specific Character Set (0008,0005) to UTF-8
    :type  convert_to_utf8: bool

    :param url_prefix: URL: string. Append specificed URL prefix to hyperlinks of referenced composite objects in the document.
    :type  url_prefix: str

    :param html_32: use only HTML version 3.2 compatible features
    :type  html_32: bool

    :param html_40: allow all HTML version 4.01 features (default)
    :type  html_40: bool

    :param xhtml_11: comply with XHTML version 1.1 specification
    :type  xhtml_11: bool

    :param add_document_type: add reference to SGML document type definition
    :type  add_document_type: bool

    :param css_reference: URL: string. Add reference to specified CSS to document
    :type  css_reference: str

    :param css_file: [f]ilename: string. Embed content of specified CSS into document
    :type  css_file: os.PathLike

    :param expand_inline: expand short content items inline (default)
    :type  expand_inline: bool

    :param never_expand_inline: never expand content items inline
    :type  never_expand_inline: bool

    :param always_expand_inline: always expand content items inline
    :type  always_expand_inline: bool

    :param render_full_data: render full data of content items
    :type  render_full_data: bool

    :param section_title_inline: render section titles inline, not separately
    :type  section_title_inline: bool

    :param document_type_title: use document type as document title (default)
    :type  document_type_title: bool

    :param patient_info_title: use patient information as document title
    :type  patient_info_title: bool

    :param no_document_header: do not render general document information
    :type  no_document_header: bool

    :param render_inline_codes: render codes in continuous text blocks
    :type  render_inline_codes: bool

    :param concept_name_codes: render code of concept names
    :type  concept_name_codes: bool

    :param numeric_unit_codes: render code of numeric measurement units
    :type  numeric_unit_codes: bool

    :param code_value_unit: use code value as measurement unit (default)
    :type  code_value_unit: bool

    :param code_meaning_unit: use code meaning as measurement unit
    :type  code_meaning_unit: bool

    :param render_all_codes: render all codes (implies +Ci, +Cn and +Cu)
    :type  render_all_codes: bool

    :param code_details_tooltip: render code details as a tooltip (implies +Cc)
    :type  code_details_tooltip: bool

    :return: Output text file
    :rtype:  str
    """
    js_module = await js_package.js_module
    web_worker = js_resources.web_worker

    kwargs = {}
    if read_file_only:
        kwargs["readFileOnly"] = to_js(read_file_only)
    if read_dataset:
        kwargs["readDataset"] = to_js(read_dataset)
    if read_xfer_auto:
        kwargs["readXferAuto"] = to_js(read_xfer_auto)
    if read_xfer_detect:
        kwargs["readXferDetect"] = to_js(read_xfer_detect)
    if read_xfer_little:
        kwargs["readXferLittle"] = to_js(read_xfer_little)
    if read_xfer_big:
        kwargs["readXferBig"] = to_js(read_xfer_big)
    if read_xfer_implicit:
        kwargs["readXferImplicit"] = to_js(read_xfer_implicit)
    if processing_details:
        kwargs["processingDetails"] = to_js(processing_details)
    if unknown_relationship:
        kwargs["unknownRelationship"] = to_js(unknown_relationship)
    if invalid_item_value:
        kwargs["invalidItemValue"] = to_js(invalid_item_value)
    if ignore_constraints:
        kwargs["ignoreConstraints"] = to_js(ignore_constraints)
    if ignore_item_errors:
        kwargs["ignoreItemErrors"] = to_js(ignore_item_errors)
    if skip_invalid_items:
        kwargs["skipInvalidItems"] = to_js(skip_invalid_items)
    if disable_vr_checker:
        kwargs["disableVrChecker"] = to_js(disable_vr_checker)
    if charset_require:
        kwargs["charsetRequire"] = to_js(charset_require)
    if charset_assume:
        kwargs["charsetAssume"] = to_js(charset_assume)
    if charset_check_all:
        kwargs["charsetCheckAll"] = to_js(charset_check_all)
    if convert_to_utf8:
        kwargs["convertToUtf8"] = to_js(convert_to_utf8)
    if url_prefix:
        kwargs["urlPrefix"] = to_js(url_prefix)
    if html_32:
        kwargs["html32"] = to_js(html_32)
    if html_40:
        kwargs["html40"] = to_js(html_40)
    if xhtml_11:
        kwargs["xhtml11"] = to_js(xhtml_11)
    if add_document_type:
        kwargs["addDocumentType"] = to_js(add_document_type)
    if css_reference is not None:
        kwargs["cssReference"] = to_js(css_reference)
    if css_file is not None:
        kwargs["cssFile"] = to_js(TextFile(css_file))
    if expand_inline:
        kwargs["expandInline"] = to_js(expand_inline)
    if never_expand_inline:
        kwargs["neverExpandInline"] = to_js(never_expand_inline)
    if always_expand_inline:
        kwargs["alwaysExpandInline"] = to_js(always_expand_inline)
    if render_full_data:
        kwargs["renderFullData"] = to_js(render_full_data)
    if section_title_inline:
        kwargs["sectionTitleInline"] = to_js(section_title_inline)
    if document_type_title:
        kwargs["documentTypeTitle"] = to_js(document_type_title)
    if patient_info_title:
        kwargs["patientInfoTitle"] = to_js(patient_info_title)
    if no_document_header:
        kwargs["noDocumentHeader"] = to_js(no_document_header)
    if render_inline_codes:
        kwargs["renderInlineCodes"] = to_js(render_inline_codes)
    if concept_name_codes:
        kwargs["conceptNameCodes"] = to_js(concept_name_codes)
    if numeric_unit_codes:
        kwargs["numericUnitCodes"] = to_js(numeric_unit_codes)
    if code_value_unit:
        kwargs["codeValueUnit"] = to_js(code_value_unit)
    if code_meaning_unit:
        kwargs["codeMeaningUnit"] = to_js(code_meaning_unit)
    if render_all_codes:
        kwargs["renderAllCodes"] = to_js(render_all_codes)
    if code_details_tooltip:
        kwargs["codeDetailsTooltip"] = to_js(code_details_tooltip)

    outputs = await js_module.structuredReportToHtml(web_worker, to_js(BinaryFile(dicom_file)), **kwargs)

    output_web_worker = None
    output_list = []
    outputs_object_map = outputs.as_object_map()
    for output_name in outputs.object_keys():
        if output_name == 'webWorker':
            output_web_worker = outputs_object_map[output_name]
        else:
            output_list.append(to_py(outputs_object_map[output_name]))

    js_resources.web_worker = output_web_worker

    if len(output_list) == 1:
        return output_list[0]
    return tuple(output_list)



"""itkwasm-dicom-emscripten: Read files and images related to DICOM file format. Emscripten implementation."""

from .apply_presentation_state_to_image_async import apply_presentation_state_to_image_async
from .read_dicom_encapsulated_pdf_async import read_dicom_encapsulated_pdf_async
from .structured_report_to_html_async import structured_report_to_html_async
from .structured_report_to_text_async import structured_report_to_text_async
from .read_image_dicom_file_series_async import read_image_dicom_file_series_async

from ._version import __version__



from pathlib import Path
import os
from typing import Dict, Tuple, Optional, List, Any

from .js_package import js_package

from itkwasm.pyodide import (
    to_js,
    to_py,
    js_resources
)
from itkwasm import (
    InterfaceTypes,
    BinaryFile,
    Image,
)

async def apply_presentation_state_to_image_async(
    image_in: os.PathLike,
    presentation_state_file: os.PathLike,
    color_output: bool = False,
    config_file: str = "",
    frame: int = 1,
    no_presentation_state_output: bool = False,
    no_bitmap_output: bool = False,
) -> Tuple[Dict, Image]:
    """Apply a presentation state to a given DICOM image and render output as bitmap, or dicom file.

    :param image_in: Input DICOM file
    :type  image_in: os.PathLike

    :param presentation_state_file: Process using presentation state file
    :type  presentation_state_file: os.PathLike

    :param color_output: output image as RGB (default: false)
    :type  color_output: bool

    :param config_file: filename: string. Process using settings from configuration file
    :type  config_file: str

    :param frame: frame: integer. Process using image frame f (default: 1)
    :type  frame: int

    :param no_presentation_state_output: Do not get presentation state information in text stream.
    :type  no_presentation_state_output: bool

    :param no_bitmap_output: Do not get resulting image as bitmap output stream.
    :type  no_bitmap_output: bool

    :return: Output overlay information
    :rtype:  Dict

    :return: Output image
    :rtype:  Image
    """
    js_module = await js_package.js_module
    web_worker = js_resources.web_worker

    kwargs = {}
    if color_output:
        kwargs["colorOutput"] = to_js(color_output)
    if config_file:
        kwargs["configFile"] = to_js(config_file)
    if frame:
        kwargs["frame"] = to_js(frame)
    if no_presentation_state_output:
        kwargs["noPresentationStateOutput"] = to_js(no_presentation_state_output)
    if no_bitmap_output:
        kwargs["noBitmapOutput"] = to_js(no_bitmap_output)

    outputs = await js_module.applyPresentationStateToImage(web_worker, to_js(BinaryFile(image_in)), to_js(BinaryFile(presentation_state_file)), **kwargs)

    output_web_worker = None
    output_list = []
    outputs_object_map = outputs.as_object_map()
    for output_name in outputs.object_keys():
        if output_name == 'webWorker':
            output_web_worker = outputs_object_map[output_name]
        else:
            output_list.append(to_py(outputs_object_map[output_name]))

    js_resources.web_worker = output_web_worker

    if len(output_list) == 1:
        return output_list[0]
    return tuple(output_list)



from pathlib import Path
import os
from typing import Dict, Tuple, Optional, List

from .js_package import js_package

from itkwasm.pyodide import (
    to_js,
    to_py,
    js_resources
)
from itkwasm import (
    InterfaceTypes,
    Image,
    BinaryFile,
)

async def read_image_dicom_file_series_async(
    input_images: List[os.PathLike] = [],
    single_sorted_series: bool = False,
) -> Tuple[Image, List[str]]:
    """Read a DICOM image series and return the associated image volume

    :param input_images: File names in the series
    :type  input_images: os.PathLike

    :param single_sorted_series: The input files are a single sorted series
    :type  single_sorted_series: bool

    :return: Output image volume
    :rtype:  Image

    :return: Output sorted filenames
    :rtype:  List[str]
    """
    js_module = await js_package.js_module
    web_worker = js_resources.web_worker

    kwargs = {}
    if input_images is not None:
        kwargs["inputImages"] = to_js(BinaryFile(input_images))
    if single_sorted_series:
        kwargs["singleSortedSeries"] = to_js(single_sorted_series)

    outputs = await js_module.readImageDicomFileSeries(web_worker, **kwargs)

    output_web_worker = None
    output_list = []
    outputs_object_map = outputs.as_object_map()
    for output_name in outputs.object_keys():
        if output_name == 'webWorker':
            output_web_worker = outputs_object_map[output_name]
        else:
            output_list.append(to_py(outputs_object_map[output_name]))

    js_resources.web_worker = output_web_worker

    if len(output_list) == 1:
        return output_list[0]
    return tuple(output_list)
